Citations
=========
Albumentations is widely used in research areas related to computer vision and deep learning.
If you find this library useful for your research, please consider citing:

::

  @article{2018arXiv180906839B,
    author = {A. Buslaev, A. Parinov, E. Khvedchenya, V.~I. Iglovikov and A.~A. Kalinin},
    title = "{Albumentations: fast and flexible image augmentations}",
    journal = {ArXiv e-prints},
    eprint = {1809.06839},
    year = 2018
  }

List of papers that cites Albumentations
----------------------------------------
1. `Camera Model Identification Using Convolutional Neural Networks <https://ieeexplore.ieee.org/abstract/document/8622031/>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
October 2018 - `A Kuzin <https://scholar.google.com/citations?user=lHjLPBsAAAAJ&hl=en&oi=sra>`_, A Fattakhov, I Kibardin.

2. `Automatic lesion boundary detection in dermoscopy <https://arxiv.org/abs/1812.00877>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
December 2018 - G Kechyn.

3. `Automatic salt deposits segmentation: A deep learning approach <https://arxiv.org/abs/1812.01429>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
December 2018 - M Karchevskiy, `I Ashrapov <https://scholar.google.com/citations?user=eTn5PTIAAAAJ&hl=en&oi=sra>`_, L Kozinkin.

4. `Adapting Convolutional Neural Networks for Geographical Domain Shift <https://arxiv.org/abs/1901.06345>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
January 2019 - `P Ostyakov <https://scholar.google.com/citations?user=mREcLI8AAAAJ&hl=en&oi=sra>`_, `SI Nikolenko <https://scholar.google.com/citations?user=_lk95cEAAAAJ&hl=en&oi=sra>`_.

5. `Cell Nuclear Morphology Analysis Using 3D Shape Modeling, Machine Learning and Visual Analytics <https://deepblue.lib.umich.edu/handle/2027.42/147598>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
February 2019 - `A Kalinin <https://scholar.google.com/citations?user=oEHDAgMAAAAJ&hl=en&oi=sra>`_.

6. `Safe Augmentation: Learning Task-Specific Transformations from Data <https://arxiv.org/abs/1907.12896>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
February 2019 - I Baran, `O Kupyn <https://scholar.google.com/citations?user=Yl1Lu2YAAAAJ&hl=en&oi=sra>`_, A Kravchenko.

7. `Self-supervised Learning for Dense Depth Estimation in Monocular Endoscopy <https://arxiv.org/abs/1902.07766>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
February 2019 - `X Liu <https://scholar.google.com/citations?user=qMxRGQkAAAAJ&hl=en&oi=sra>`_, `A Sinha <https://scholar.google.com/citations?user=RrhxYCAAAAAJ&hl=en&oi=sra>`_, M Ishii, `GD Hager <https://scholar.google.com/citations?user=ivApfKcAAAAJ&hl=en&oi=sra>`_, `A Reiter <https://scholar.google.com/citations?user=CxKgqz0AAAAJ&hl=en&oi=sra>`_.

8. `U-NetPlus: A Modified Encoder-Decoder U-Net Architecture for Semantic and Instance Segmentation of Surgical Instrument <https://arxiv.org/abs/1902.08994>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
February 2019 - `SM Hasan <https://scholar.google.com/citations?user=1-n7bwMAAAAJ&hl=en&oi=sra>`_, `CA Linte <https://scholar.google.com/citations?user=Gv4gGVsAAAAJ&hl=en&oi=sra>`_.

9. `General Purpose (GenP) Bioimage Ensemble of Handcrafted and Learned Features with Data Augmentation <https://arxiv.org/abs/1904.08084>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
March 2019 - `L Nanni <https://scholar.google.com/citations?user=5NSGzcQAAAAJ&hl=en&oi=sra>`_, `S Brahnam <https://scholar.google.com/citations?user=sYF3eJkAAAAJ&hl=en&oi=sra>`_, `S Ghidoni <https://scholar.google.com/citations?user=s5PIk-4AAAAJ&hl=en&oi=sra>`_, `G Maguolo <https://scholar.google.com/citations?user=Df9a1YkAAAAJ&hl=en&oi=sra>`_.

10. `Breast Tumor Cellularity Assessment using Deep Neural Networks <https://arxiv.org/abs/1905.01743>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
May 2019 - `A Rakhlin <https://scholar.google.com/citations?user=TIAJg3IAAAAJ&hl=en&oi=sra>`_, `AA Shvets <https://scholar.google.com/citations?user=_eJ5xysAAAAJ&hl=en&oi=sra>`_, `AA Kalinin <https://scholar.google.com/citations?user=oEHDAgMAAAAJ&hl=en&oi=sra>`_, `A Tiulpin <https://scholar.google.com/citations?user=EFE2gpQAAAAJ&hl=en&oi=sra>`_.

11. `A Deep 3D Object Pose Estimation Framework for Robots with RGB-D Sensors <https://digitalcommons.wpi.edu/etd-theses/1287/>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
June 2019 - AY Wagh.

12. `Data Augmentation From RGB to Chlorophyll Fluorescence Imaging Application to Leaf Segmentation of Arabidopsis thaliana From Top View Images <http://openaccess.thecvf.com/content_CVPRW_2019/html/CVPPP/Sapoukhina_Data_Augmentation_From_RGB_to_Chlorophyll_Fluorescence_Imaging_Application_to_CVPRW_2019_paper.html>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
June 2019 - N Sapoukhina, `S Samiei <https://scholar.google.com/citations?user=64L4ImgAAAAJ&hl=en&oi=sra>`_, `P Rasti <https://scholar.google.com/citations?user=hl8Jyr4AAAAJ&hl=en&oi=sra>`_.

13. `CLoDSA: a tool for augmentation in classification, localization, detection, semantic segmentation and instance segmentation tasks <https://bmcbioinformatics.biomedcentral.com/articles/10.1186/s12859-019-2931-1>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
June 2019 - Á Casado-García, C Domínguez.

14. `Urban Sound Tagging using Convolutional Neural Networks <https://arxiv.org/abs/1909.12699>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
July 2019 - `S Adapa <https://scholar.google.com/citations?user=SJUsAwsAAAAJ&hl=en&oi=sra>`_.

15. `A Framework for Knowing Who is Doing What in Aerial Surveillance Videos <https://ieeexplore.ieee.org/abstract/document/8753491/>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
July 2019 - `F Yang <https://scholar.google.com/citations?user=LndV87gAAAAJ&hl=en&oi=sra>`_, `S Sakti <https://scholar.google.com/citations?user=E0uhtlkAAAAJ&hl=en&oi=sra>`_, Y Wu, S Nakamura.

16. `Visual Anomaly Detection For Automatic Quality Control <https://boa.unimib.it/handle/10281/241219>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
July 2019 - `F Piccoli <https://scholar.google.com/citations?user=qBoFeZoAAAAJ&hl=en&oi=sra>`_.

17. `Physical Cue based Depth-Sensing by Color Coding with Deaberration Network <https://arxiv.org/abs/1908.00329>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
August 2019 - N Mishima, T Kozakaya, A Moriya, R Okada.

18. `Bayesian Feature Pyramid Networks for Automatic Multi-Label Segmentation of Chest X-rays and Assessment of Cardio-Thoratic Ratio <https://arxiv.org/abs/1908.02924>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
August 2019 - R Solovyev, `I Melekhov <https://scholar.google.com/citations?user=BXNprrsAAAAJ&hl=en&oi=sra>`_, T Lesonen.

19. `DeblurGAN-v2: Deblurring (Orders-of-Magnitude) Faster and Better <https://arxiv.org/abs/1908.03826>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
August 2019 - `O Kupyn <https://scholar.google.com/citations?user=Yl1Lu2YAAAAJ&hl=en&oi=sra>`_, `T Martyniuk <https://scholar.google.com/citations?user=Ur0vgfMAAAAJ&hl=en&oi=sra>`_, `J Wu <https://scholar.google.com/citations?user=nBbGvyEAAAAJ&hl=en&oi=sra>`_, `Z Wang <https://scholar.google.com/citations?user=pxFyKAIAAAAJ&hl=en&oi=sra>`_.

20. `The Impact of Padding on Image Classification by Using Pre-trained Convolutional Neural Networks <https://link.springer.com/chapter/10.1007/978-3-030-30645-8_31>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
September 2019 - H Tang, `A Ortis <https://scholar.google.com/citations?user=gcztqXgAAAAJ&hl=en&oi=sra>`_, `S Battiato <https://scholar.google.com/citations?user=OplbtHgAAAAJ&hl=en&oi=sra>`_.

21. `A load frame for in situ tomography at PETRA III <https://www.spiedigitallibrary.org/conference-proceedings-of-spie/11113/1111318/A-load-frame-for-in-situ-tomography-at-PETRA-III/10.1117/12.2530445.short>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
September 2019 - J Moosmann, DCF Wieland.

22. `Deep convolutions for in-depth automated rock typing <https://www.sciencedirect.com/science/article/pii/S0098300419304686>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
September 2019 - EE Baraboshkin, `LS Ismailova <https://scholar.google.com/citations?user=-ZP9a8YAAAAJ&hl=en&oi=sra>`_, `DM Orlov <https://scholar.google.com/citations?user=jP69FIgAAAAJ&hl=en&oi=sra>`_.

23. `残差密集相对平均 CGAN 的图像配准方法 <http://www.cjig.cn/jig/ch/reader/download_new_edit_content.aspx?edit_id=20190926091554001&file_no=201903270000001&journal_id=jig>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
September 2019 - 王丽芳， 张程程， 秦品乐， 蔺素珍， 高媛， 窦杰亮.

24. `Cloud Recognition and Masking of Earth Observation Imagery-An Optimized approach for Automatic Labeling of Sentinel-2 Imagery for Object Detection <https://ntnuopen.ntnu.no/ntnu-xmlui/handle/11250/2619036>`_.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
September 2019 - LM Ellefsen.
